@@ -1,12 +1,13 @@
 from typing import Dict
 from dateutil import rrule
+from windyquery.exceptions import RruleNoResults
 
 from ._crud_base import CrudBase
 
 
 class Rrule(CrudBase):
 
-    def rrule(self, name: str, *items: Dict):
+    def rrule(self, name: str, *items: Dict, occurrences: slice = slice(100000)):
         if len(items) == 0:
             raise UserWarning('rrule cannot be empty')
         columns = list(items[0].keys())
@@ -27,7 +28,7 @@ class Rrule(CrudBase):
                         raise UserWarning(f'invalid rrule: {colVal}') from None
                 val.append(colVal)
             values.append(val)
-        self.collector.rrule(name, rrulepos, columns, values)
+        self.collector.rrule(name, rrulepos, columns, values, occurrences)
         return self
 
     def build_rrule(self, items) -> str:
@@ -36,6 +37,9 @@ class Rrule(CrudBase):
             name = item['name']
             columns = item['columns']
             values = item['values']
+            if not values:
+                raise RruleNoResults(
+                    f'the rrule for {name} returns no results')
             parsedItem = f'{name} {columns} AS (VALUES {values})'
             parsedItems.append(parsedItem)
         sql = 'WITH ' + ', '.join(parsedItems)
