@@ -18,7 +18,7 @@ class RruleToken(LexToken):
 
 
 class Rrule(Base):
-    def rrule(self, name: str, rrulepos: int, columns: List[str], values: List[Any]):
+    def rrule(self, name: str, rrulepos: int, columns: List[str], values: List[Any], occurrences: slice):
         try:
             name = self.validator.validate_identifier(name)
             sqlColumns = self.validator.validate_rrule_columns(columns)
@@ -26,10 +26,12 @@ class Rrule(Base):
             args = []
             for row in values:
                 ctx = Ctx(self.paramOffset, [])
-                sqlValues.append(
-                    self.validator.validate_rrule_values(rrulepos, row, ctx))
-                self.paramOffset += len(ctx.args)
-                args += ctx.args
+                sqlVal = self.validator.validate_rrule_values(
+                    rrulepos, row, ctx, occurrences)
+                if sqlVal:
+                    sqlValues.append(sqlVal)
+                    self.paramOffset += len(ctx.args)
+                    args += ctx.args
         except ValidationError as err:
             raise UserWarning(f'invalid RRULE: {err}') from None
 
