@@ -1,7 +1,9 @@
 import asyncio
 import datetime
+import pytest
 
 from windyquery import DB
+from windyquery.exceptions import RruleNoResults
 
 loop = asyncio.get_event_loop()
 
@@ -155,3 +157,40 @@ def test_rrule_raw(db: DB):
     assert rows[0]['task_id'] == 3
     assert rows[1]['task_id'] == 3
     assert rows[2]['task_id'] == 3
+
+
+def test_rrule_slice(db: DB):
+    rruleStr3 = """
+    DTSTART:20210203T100000Z
+    RRULE:FREQ=DAILY
+    """
+    rows = loop.run_until_complete(db.rrule('task_rrules', {'rrule': rruleStr3}, occurrences=slice(
+        3)).table('task_rrules').select('task_rrules.rrule'))
+    assert len(rows) == 3
+    assert rows[0]['rrule'] == datetime.datetime(
+        2021, 2, 3, 10, 0, tzinfo=datetime.timezone.utc)
+    assert rows[1]['rrule'] == datetime.datetime(
+        2021, 2, 4, 10, 0, tzinfo=datetime.timezone.utc)
+    assert rows[2]['rrule'] == datetime.datetime(
+        2021, 2, 5, 10, 0, tzinfo=datetime.timezone.utc)
+
+    rows = loop.run_until_complete(db.rrule('task_rrules', {'rrule': rruleStr3}, occurrences=slice(
+        10, 20, 2)).table('task_rrules').select('task_rrules.rrule'))
+    assert len(rows) == 5
+    assert rows[0]['rrule'] == datetime.datetime(
+        2021, 2, 13, 10, 0, tzinfo=datetime.timezone.utc)
+    assert rows[1]['rrule'] == datetime.datetime(
+        2021, 2, 15, 10, 0, tzinfo=datetime.timezone.utc)
+    assert rows[2]['rrule'] == datetime.datetime(
+        2021, 2, 17, 10, 0, tzinfo=datetime.timezone.utc)
+    assert rows[3]['rrule'] == datetime.datetime(
+        2021, 2, 19, 10, 0, tzinfo=datetime.timezone.utc)
+    assert rows[4]['rrule'] == datetime.datetime(
+        2021, 2, 21, 10, 0, tzinfo=datetime.timezone.utc)
+
+
+def test_rrule_no_results(db: DB):
+    with pytest.raises(RruleNoResults) as excinfo:
+        loop.run_until_complete(
+            db.rrule('rrule1', {'rrule': rruleStr1}, occurrences=slice(1000, 1001)).table('rrule1').select())
+    assert type(excinfo.value) is RruleNoResults
